<map version="freeplane 1.5.9">
<!--To view this file, download free mind mapping software Freeplane from https://www.freeplane.org -->
<node TEXT="Freeplane&#xa;Functies" FOLDED="false" ID="ID_45488473" CREATED="1288535648658" MODIFIED="1321016216736" BACKGROUND_COLOR="#00ff99" VGAP_QUANTITY="0.0 px">
<icon BUILTIN="bee"/>
<font BOLD="true"/>
<hook NAME="MapStyle">
    <properties fit_to_viewport="false;" show_icon_for_attributes="false" show_note_icons="false" show_notes_in_map="false"/>

<map_styles>
<stylenode LOCALIZED_TEXT="styles.root_node" STYLE="oval" UNIFORM_SHAPE="true" VGAP_QUANTITY="24.0 pt">
<font SIZE="24"/>
<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="default" FORMAT_AS_HYPERLINK="true" COLOR="#000000" STYLE="fork" MAX_WIDTH="600.0 px" MIN_WIDTH="1.0 px">
<font NAME="SansSerif" SIZE="8" BOLD="false" ITALIC="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.details"/>
<stylenode LOCALIZED_TEXT="defaultstyle.attributes">
<font SIZE="9"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.note"/>
<stylenode LOCALIZED_TEXT="defaultstyle.floating">
<edge STYLE="hide_edge"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.ok">
<icon BUILTIN="button_ok"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.needs_action">
<icon BUILTIN="messagebox_warning"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.floating_node">
<cloud COLOR="#ffffff" SHAPE="ARC"/>
<edge STYLE="hide_edge"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.topic" COLOR="#18898b" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
<edge STYLE="bezier" COLOR="#808080" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subtopic" COLOR="#cc3300" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
<edge STYLE="bezier" COLOR="#808080" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subsubtopic" COLOR="#669900">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.connection" COLOR="#606060" STYLE="fork">
<font NAME="Arial" SIZE="10" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.important" COLOR="#ff0000">
<icon BUILTIN="yes"/>
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.question">
<icon BUILTIN="help"/>
<font NAME="Aharoni" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.key" COLOR="#996600">
<icon BUILTIN="password"/>
<font NAME="Liberation Sans" SIZE="12" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.idea">
<icon BUILTIN="idea"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.note" COLOR="#990000">
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.date" COLOR="#0033ff">
<icon BUILTIN="calendar"/>
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.website" COLOR="#006633">
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.list" COLOR="#cc6600">
<icon BUILTIN="list"/>
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.quotation" COLOR="#338800" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="false" ITALIC="false"/>
<edge STYLE="bezier" COLOR="#808080" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.definition" COLOR="#666600">
<font NAME="Liberation Sans" SIZE="12" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.description" COLOR="#996600">
<font NAME="Liberation Sans" SIZE="12" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.pending" COLOR="#b3b95c">
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" COLOR="#000000">
<font SIZE="20"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,1" COLOR="#0033ff">
<font SIZE="18"/>
<edge WIDTH="8"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,2" COLOR="#00b439">
<font SIZE="16"/>
<edge STYLE="bezier" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,3" COLOR="#990000">
<font SIZE="14"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,4" COLOR="#111111">
<font SIZE="12"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right" STYLE="bubble">
<stylenode TEXT="Reference">
<icon BUILTIN="help"/>
<edge STYLE="hide_edge"/>
<font BOLD="true"/>
<cloud COLOR="#99ffff" SHAPE="ROUND_RECT"/>
</stylenode>
<stylenode TEXT="Note" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<edge STYLE="hide_edge"/>
</stylenode>
</stylenode>
</stylenode>
</map_styles>
</hook>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Beweeg met de cursor over de teksten om hyperlinks zichtbaar te maken naar de <b><i>Handleiding</i></b>&#160;en de <i><b>Documentatie</b></i>.
    </p>
    <p>
      
    </p>
    <p>
      N.B. Dit is een <b>Notitie tekst</b>..
    </p>
    <p>
      
    </p>
    <p>
      Om het notitiepaneel aan/uit te schakeln:
    </p>
    <ul>
      <li>
        <i>Beeld &gt; Notities &gt; Toon notitievenster. </i>
      </li>

    </ul>
  </body>
</html>
</richcontent>
<node TEXT="In knoopkern" POSITION="left" ID="ID_1556354626" CREATED="1319792091506" MODIFIED="1323790447061" HGAP_QUANTITY="5.0 px" VSHIFT_QUANTITY="-40.0 px" BACKGROUND_COLOR="#ffff00" NUMBERED="true">
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>See</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1337127972">Basis mindmap</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="sharp_bezier" COLOR="#000099" WIDTH="2"/>
<node ID="ID_1266354824" CREATED="1319799106394" MODIFIED="1321029393560" STYLE="bubble" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p style="text-align: center">
      <b>Tekst </b>&#160;met <a href="http://www.freeplane.org">onderstreepte hyperlink(s)</a>, en:
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_268413071">Bewerken &gt; Knoopkern tekst</a>&#160;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal" WIDTH="thin"/>
</node>
<node ID="ID_300419503" CREATED="1319798221748" MODIFIED="1336132643156" HGAP_QUANTITY="363.0 px" VSHIFT_QUANTITY="-71.0 px" STYLE="bubble"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <img src="Images/doc/freeplaneApplications.png"/>
  </body>
</html>

</richcontent>
<hook NAME="FreeNode"/>
<edge STYLE="hide_edge"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1795262306">Afbeelding (knoopkern)</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="Interne pijl-koppeling, of" ID="ID_1519332680" CREATED="1288542452827" MODIFIED="1323788864205" LINK="#ID_784697063" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-2.0 px" TEXT_SHORTENED="true">
<edge STYLE="horizontal" WIDTH="thin"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1830541497">Groene-pijl koppeling</a>&#160;
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="Externe pijl-koppeling, en" ID="ID_1537075496" CREATED="1288542605210" MODIFIED="1323788903922" LINK="http://kioo.nl/" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-3.0 px" TEXT_SHORTENED="true">
<edge STYLE="horizontal" WIDTH="thin"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1913035829">Rode-pijlkoppeling</a>&#160;
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="Pictogrammen" ID="ID_233656995" CREATED="1288542843639" MODIFIED="1323788954544" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-7.0 px" TEXT_SHORTENED="true">
<icon BUILTIN="bookmark"/>
<icon BUILTIN="button_ok"/>
<icon BUILTIN="closed"/>
<edge STYLE="horizontal" WIDTH="thin"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_715025500">Pictogrammen</a>&#160;
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="% Schijf" ID="ID_1826346574" CREATED="1319793474635" MODIFIED="1323788989785">
<icon BUILTIN="25%"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_707469329">% Schijf</a>&#160;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal" WIDTH="thin"/>
</node>
<node TEXT="Automatisch knoopnummer" ID="ID_1097461051" CREATED="1305277030363" MODIFIED="1323789027334" NUMBERED="true" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1531819965">Automatische knoopnummering</a>&#160;
      </li>

    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal" WIDTH="thin"/>
</node>
</node>
<node TEXT="Vrij positioneerbare knoop" POSITION="left" ID="ID_1280208201" CREATED="1319797134021" MODIFIED="1323789119624" HGAP_QUANTITY="140.0 px" VSHIFT_QUANTITY="19.0 px" TEXT_SHORTENED="true">
<hook NAME="FreeNode"/>
<font BOLD="true"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1401167294">Vrije (zwevende) knoop</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Toestand
    </p>
  </body>
</html>
</richcontent>
<node TEXT="Zwevende knoop" LOCALIZED_STYLE_REF="defaultstyle.floating" ID="ID_231217112" CREATED="1319797190586" MODIFIED="1323789155332" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true">
<font BOLD="true"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1401167294">Vrije (zwevende) knoop</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Standard Style
    </p>
  </body>
</html>
</richcontent>
</node>
</node>
<node POSITION="right" ID="ID_1077719150" CREATED="1319792123071" MODIFIED="1321038005400" VGAP_QUANTITY="0.0 px" HGAP_QUANTITY="-10.0 px" BACKGROUND_COLOR="#ffff00" NUMBERED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <i>Onder de knoopkern:</i>
    </p>
    <p>
      <b>Knoopuitbreidingen</b>
    </p>
  </body>
</html>

</richcontent>
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_143196514">Knoopuitbreiding</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="sharp_bezier" COLOR="#cc0000" WIDTH="2"/>
<node TEXT="Onder deze knoopkern:" ID="ID_1010722858" CREATED="1288646162992" MODIFIED="1336132660269" STYLE="bubble" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="-9.0 px">
<font ITALIC="false"/>
<attribute NAME="a1" VALUE="waarde 1"/>
<attribute NAME="a2" VALUE="waarde 2"/>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Tekst </b>met&#160;<a href="http://www.freeplane.org">onderstreepte hyperlink(s)</a>, en:
    </p>
  </body>
</html>
</richcontent>
<hook EQUATION="\begin{array}{l}&#xa;\mbox{I}^\fgcolor{ff0000}{\heartsuit}\mbox{\JLaTeXMath}\\&#xa;\end{array}" NAME="plugins/latex/LatexNodeHook.properties"/>
<edge STYLE="bezier" WIDTH="thin"/>
<hook URI="Images/doc/freeplaneApplications.png" SIZE="0.51111114" NAME="ExternalObject"/>
<node STYLE_REF="Reference" ID="ID_965583686" CREATED="1319872918353" MODIFIED="1321010685262" HGAP_QUANTITY="280.0 px" VSHIFT_QUANTITY="-11.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Knoopdetails</b>&#160;(tekst)
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_965583686" STARTINCLINATION="-68;21;" ENDINCLINATION="-68;21;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i><b></b>&#160;<a href="freeplaneTutorial_nl.mm#ID_898889730">Bewerken text in knoopdetails</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
</node>
<node ID="ID_242844262" CREATED="1319799725287" MODIFIED="1321011337329" HGAP_QUANTITY="390.0 px" VSHIFT_QUANTITY="39.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <i>Kan verborgen </i>
    </p>
    <p>
      <i>zijn (<b>tooltip</b>)</i>
    </p>
  </body>
</html>

</richcontent>
<hook NAME="FreeNode"/>
<edge STYLE="hide_edge"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i> <a href="freeplaneTutorial_nl.mm#ID_288274844">Toon in tooltip (zweeftekst)</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="Attributen" STYLE_REF="Reference" ID="ID_1546010515" CREATED="1319872918353" MODIFIED="1321038090373" HGAP_QUANTITY="260.0 px" VSHIFT_QUANTITY="59.0 px">
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1546010515" STARTINCLINATION="-61;0;" ENDINCLINATION="-61;0;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<hook NAME="FreeNode"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1324773677">Attributen in knoopuitbreiding</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node STYLE_REF="Reference" ID="ID_1064212525" CREATED="1319872918353" MODIFIED="1321010842194" HGAP_QUANTITY="240.0 px" VSHIFT_QUANTITY="119.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Wetenschappelijke <b>formule</b>
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1064212525" STARTINCLINATION="-94;-18;" ENDINCLINATION="-94;-18;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i><b></b>&#160;<a href="freeplaneTutorial_nl.mm#ID_616494746">Wetenschappelijke formule</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
</node>
<node STYLE_REF="Reference" ID="ID_1639134686" CREATED="1319873881764" MODIFIED="1323790279907" HGAP_QUANTITY="-20.0 px" VSHIFT_QUANTITY="90.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Schaalbaar <b>plaatje</b>&#160;(&#233;&#233;n)
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1639134686" STARTINCLINATION="-108;-23;" ENDINCLINATION="-108;-23;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i>&#160;<a href="freeplaneTutorial_nl.mm#ID_575269438">Afbeelding</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node ID="ID_1802101455" CREATED="1319799725287" MODIFIED="1321016344016" HGAP_QUANTITY="200.0 px" VSHIFT_QUANTITY="209.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <i>Stel hier </i>
    </p>
    <p>
      <i>grootte in</i>
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1802101455" STARTINCLINATION="-53;-31;" ENDINCLINATION="-53;-31;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<edge STYLE="hide_edge"/>
<hook NAME="FreeNode"/>
</node>
</node>
<node TEXT="Takken" STYLE_REF="Reference" FOLDED="true" ID="ID_1944496966" CREATED="1319872918353" MODIFIED="1321010423422" HGAP_QUANTITY="-60.0 px" VSHIFT_QUANTITY="-91.0 px">
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-28;99;" ENDINCLINATION="-28;99;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="120;32;" ENDINCLINATION="120;32;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-121;31;" ENDINCLINATION="-121;31;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i><b>&#160;<a href="freeplaneTutorial_nl.mm#ID_1812601804">Opmaakpaneel,</a>&#160;</b>&#160;<a href="freeplaneTutorial#ID_1492225657">Takken</a>&#160;and <a href="freeplaneTutorial_nl.mm#ID_1005719714">Automatische takkleur</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<node TEXT="Opmaken tak" ID="ID_1601648824" CREATED="1319796287461" MODIFIED="1321037919116" HGAP_QUANTITY="30.0 px" VSHIFT_QUANTITY="-172.0 px">
<edge STYLE="bezier"/>
<node TEXT="dikte tak" ID="ID_241458321" CREATED="1288541466835" MODIFIED="1288646970331" VSHIFT_QUANTITY="7.0 px">
<node TEXT="dun" ID="ID_1693976270" CREATED="1288541473878" MODIFIED="1288541507504" HGAP_QUANTITY="42.0 px"/>
<node TEXT="punt 3" ID="ID_1152182019" CREATED="1288542920337" MODIFIED="1288542944097" HGAP_QUANTITY="42.0 px" VSHIFT_QUANTITY="9.0 px">
<edge WIDTH="2"/>
</node>
<node TEXT="punt 8" ID="ID_1828139471" CREATED="1288541479345" MODIFIED="1288542967746" HGAP_QUANTITY="42.0 px" VSHIFT_QUANTITY="5.0 px">
<edge WIDTH="8"/>
</node>
</node>
<node TEXT="vorm tak" ID="ID_784697063" CREATED="1288536745875" MODIFIED="1289122245318" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="1.0 px">
<node TEXT="Rechte lijn" ID="ID_884692926" CREATED="1288538234095" MODIFIED="1305276198448" HGAP_QUANTITY="53.0 px" VSHIFT_QUANTITY="-1.0 px">
<edge STYLE="linear" WIDTH="4"/>
</node>
<node TEXT="Bocht" ID="ID_609820168" CREATED="1288538240451" MODIFIED="1288539867421" HGAP_QUANTITY="57.0 px" VSHIFT_QUANTITY="9.0 px">
<edge STYLE="bezier" WIDTH="4"/>
</node>
<node TEXT="Taps toelopend recht" ID="ID_1647821228" CREATED="1288538242377" MODIFIED="1288540221963" HGAP_QUANTITY="60.0 px" VSHIFT_QUANTITY="10.0 px">
<edge STYLE="sharp_linear" WIDTH="4"/>
</node>
<node TEXT="Taps toelopend bocht" ID="ID_895403951" CREATED="1288538470332" MODIFIED="1288540434497" HGAP_QUANTITY="70.0 px" VSHIFT_QUANTITY="15.0 px">
<edge STYLE="sharp_bezier" WIDTH="4"/>
</node>
<node TEXT="Verborgen tak" ID="ID_1675552701" CREATED="1288538507390" MODIFIED="1288548679856" HGAP_QUANTITY="77.0 px" VSHIFT_QUANTITY="18.0 px" BACKGROUND_COLOR="#00ffff">
<edge STYLE="hide_edge" WIDTH="4"/>
</node>
</node>
<node TEXT="takkleur" ID="ID_939577724" CREATED="1288536788635" MODIFIED="1288542068616">
<edge COLOR="#ff0066"/>
</node>
</node>
</node>
</node>
<node POSITION="right" ID="ID_1125102706" CREATED="1319918074662" MODIFIED="1321011244096" BACKGROUND_COLOR="#ffff00" NUMBERED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <i>Onder knoopuitbreidingen </i>
    </p>
    <p>
      <i>of in apart vester: </i><b>Notitie</b>
    </p>
  </body>
</html>

</richcontent>
<edge STYLE="sharp_bezier" COLOR="#006633" WIDTH="2"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_274601394">Note</a>&#160;
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="Wolk" STYLE_REF="Reference" FOLDED="true" POSITION="right" ID="ID_1697684606" CREATED="1319873881764" MODIFIED="1323790359358" HGAP_QUANTITY="550.0 px" VSHIFT_QUANTITY="79.0 px">
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1697684606" STARTINCLINATION="-90;73;" ENDINCLINATION="-90;73;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1150908697">Groep knopen binnen een wolk</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<node TEXT="rechthoek" ID="ID_1198357672" CREATED="1305277572322" MODIFIED="1321038483416" HGAP_QUANTITY="48.0 px" VSHIFT_QUANTITY="4.0 px">
<cloud COLOR="#f0f0f0" SHAPE="RECT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1150908697">Cloud node group</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="ster" ID="ID_1434127019" CREATED="1305277804466" MODIFIED="1321038476333">
<cloud COLOR="#f0f0f0" SHAPE="STAR"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1150908697">Knoopgroep wolk</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
</node>
<node TEXT="Relaties" POSITION="right" ID="ID_441663322" CREATED="1288536353356" MODIFIED="1321011073861" STYLE="fork" HGAP_QUANTITY="-41.0 px" VSHIFT_QUANTITY="37.0 px"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <a href="freeplaneTutorial_nl.mm#ID_448981847">&#160;xx</a>&#160;
    </p>
  </body>
</html>
</richcontent>
<cloud COLOR="#f0f0f0" SHAPE="ARC"/>
<node TEXT="boven a" ID="ID_1863548649" CREATED="1288536207761" MODIFIED="1321011061055" HGAP_QUANTITY="37.0 px" VSHIFT_QUANTITY="-13.0 px" STYLE="bubble"/>
<node TEXT="knoop a" ID="ID_1119041406" CREATED="1288535672221" MODIFIED="1336118905285" STYLE="bubble" HGAP_QUANTITY="53.0 px" VSHIFT_QUANTITY="7.0 px">
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#ff0000" WIDTH="5" TRANSPARENCY="80" FONT_SIZE="8" FONT_FAMILY="SansSerif" DESTINATION="ID_268922755" SOURCE_LABEL="ouder" TARGET_LABEL="kleinkind" MIDDLE_LABEL="hierarchie" STARTINCLINATION="-2;23;" ENDINCLINATION="-21;59;" STARTARROW="NONE" ENDARROW="NONE"/>
<node TEXT="knoop b" ID="ID_1908863616" CREATED="1288535688688" MODIFIED="1321011087862" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="10.0 px" STYLE="bubble">
<edge STYLE="bezier" WIDTH="thin"/>
<node ID="ID_1947425814" CREATED="1319799725287" MODIFIED="1323790434784" HGAP_QUANTITY="5.0 px" VSHIFT_QUANTITY="-46.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Indicator <b>tool tip</b>
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1947425814" STARTINCLINATION="4;47;" ENDINCLINATION="4;47;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<edge STYLE="hide_edge"/>
<hook NAME="FreeNode"/>
</node>
<node ID="ID_1143366438" CREATED="1319799725287" MODIFIED="1323790424238" HGAP_QUANTITY="105.0 px" VSHIFT_QUANTITY="-21.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      Indicator&#160;<b>Openvouwen</b>
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1143366438" STARTINCLINATION="-41;22;" ENDINCLINATION="-41;22;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<font BOLD="false"/>
<edge STYLE="hide_edge"/>
<hook NAME="FreeNode"/>
</node>
<node TEXT="knoop c" FOLDED="true" ID="ID_268922755" CREATED="1288535699522" MODIFIED="1321011094420" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true" STYLE="bubble"><richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      This text only
    </p>
    <p>
      appears in
    </p>
    <p>
      <b>tool tip</b>
    </p>
  </body>
</html>
</richcontent>
<node TEXT="etc." ID="ID_1829616131" CREATED="1319919735822" MODIFIED="1319919743997"/>
</node>
<node STYLE_REF="Reference" ID="ID_389809087" CREATED="1319872918353" MODIFIED="1321039088884" HGAP_QUANTITY="140.0 px" VSHIFT_QUANTITY="79.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Verbinding</b>
    </p>
    <p>
      (bilateraal)
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_389809087" STARTINCLINATION="-80;-24;" ENDINCLINATION="-80;-24;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1073407528">Verbindingslijn</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
</node>
<node TEXT="Label" STYLE_REF="Reference" ID="ID_1560136360" CREATED="1319872918353" MODIFIED="1321039208926" HGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="99.0 px">
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1560136360" STARTINCLINATION="-4;-35;" ENDINCLINATION="-4;-35;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1073407528">Verbinding</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
</node>
</node>
</node>
<node TEXT="onder a" ID="ID_975219834" CREATED="1288536218798" MODIFIED="1321011102143" HGAP_QUANTITY="27.0 px" VSHIFT_QUANTITY="34.0 px" STYLE="bubble"/>
</node>
<node STYLE_REF="Reference" POSITION="right" ID="ID_1828022839" CREATED="1319963720129" MODIFIED="1321010997120" HGAP_QUANTITY="524.0 px" VSHIFT_QUANTITY="189.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Verbindingslijn</b>
    </p>
    <p>
      (unilateraal)
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1828022839" STARTINCLINATION="-46;-50;" ENDINCLINATION="-46;-50;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding:<b>&#160;</b></i><b></b>&#160;<a href="freeplaneTutorial_nl.mm#ID_1073407528">Verbinding</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="Opmaken knoopkern" FOLDED="true" POSITION="left" ID="ID_1983670807" CREATED="1319795759589" MODIFIED="1321035141763" HGAP_QUANTITY="10.0 px" VSHIFT_QUANTITY="49.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1778719162">Opmaken en stylen</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<node TEXT="Omlijnde knoopkern" ID="ID_1794331644" CREATED="1288536624648" MODIFIED="1321037674632" STYLE="bubble" VSHIFT_QUANTITY="110.0 px"/>
<node TEXT="Kleur" ID="ID_1602479950" CREATED="1288536644733" MODIFIED="1321037781539">
<node TEXT="Knoopkleur" ID="ID_1350125844" CREATED="1288536652401" MODIFIED="1321037697705" COLOR="#ff0066"/>
<node TEXT="Knoopachtergrondkleur" ID="ID_113421480" CREATED="1288536658726" MODIFIED="1321037764067" BACKGROUND_COLOR="#00ff00"/>
<node TEXT="achtergrondkleur mindmap" ID="ID_1843027739" CREATED="1288536750875" MODIFIED="1288542075698"/>
</node>
<node TEXT="Lettertype" ID="ID_8536216" CREATED="1270892460659" MODIFIED="1321037788341">
<font NAME="SansSerif" SIZE="12"/>
<node TEXT="Times New Roman" ID="ID_1308363481" CREATED="1270892460659" MODIFIED="1271973714732">
<font NAME="Times New Roman" SIZE="16"/>
</node>
<node TEXT="Verdana" ID="ID_256616219" CREATED="1270892460659" MODIFIED="1271973720643">
<font NAME="Verdana" SIZE="12"/>
</node>
<node TEXT="Dialog font" ID="ID_825914156" CREATED="1270892460659" MODIFIED="1271973770585">
<font NAME="Dialog" SIZE="21"/>
</node>
</node>
<node TEXT="Knipperen" ID="ID_1280590016" CREATED="1288548004325" MODIFIED="1321037796874" VSHIFT_QUANTITY="-13.0 px">
<hook NAME="accessories/plugins/BlinkingNodeHook.properties"/>
</node>
</node>
<node TEXT="Vrije + zwevende knoop" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="left" ID="ID_188185624" CREATED="1319788879948" MODIFIED="1323789179419" HGAP_QUANTITY="418.0 px" VSHIFT_QUANTITY="72.0 px" TEXT_SHORTENED="true">
<hook NAME="FreeNode"/>
<font BOLD="true"/>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      (double-click free area)
    </p>
  </body>
</html>
</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1401167294">Free (floating) node</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="" POSITION="left" ID="ID_445314439" CREATED="1455910866417" MODIFIED="1455910866417">
<hook NAME="FirstGroupNode"/>
</node>
<node TEXT="Speciaal" POSITION="left" ID="ID_206364326" CREATED="1319795251644" MODIFIED="1321009985956" VSHIFT_QUANTITY="20.0 px">
<node TEXT="Beveiligen met wachtwoord" ENCRYPTED_CONTENT="t/NS/HPSppU= VbQIDGWIdFE=" ID="ID_36040841" CREATED="1288542236861" MODIFIED="1321035430738" TEXT_SHORTENED="true" HGAP_QUANTITY="30.0 px"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1232153769">Beveiligen knoop</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="Bereken = 4 + 3" ID="ID_49859005" CREATED="1319800320485" MODIFIED="1321035490783" HGAP_QUANTITY="30.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_448338872">Berekeningen uitvoeren</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<node TEXT="=3 + 4" ID="ID_38981929" CREATED="1319800292281" MODIFIED="1320162604957" TEXT_SHORTENED="true"><richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      The calculated result
    </p>
    <p>
      does not show if the
    </p>
    <p>
      map is in read only mode !
    </p>
  </body>
</html>
</richcontent>
</node>
</node>
<node TEXT="Herinnering (Agenda)" ID="ID_1885496887" CREATED="1288542096079" MODIFIED="1321035618625" HGAP_QUANTITY="31.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true">
<hook NAME="plugins/TimeManagementReminder.xml">
    <Parameters REMINDUSERAT="2077460580480" PERIOD="1" UNIT="DAY"/>
</hook>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1959496513">Datum en tijdacties</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
</node>
<node TEXT="Overig" POSITION="left" ID="ID_454770946" CREATED="1319875565802" MODIFIED="1321011282877" HGAP_QUANTITY="10.0 px" VSHIFT_QUANTITY="30.0 px">
<node TEXT="Filter en sorteer" ID="ID_1987204825" CREATED="1319925023100" MODIFIED="1321035763908" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_828862571">Filteren en zoeken</a>&#160;resp. <a href="freeplaneTutorial_nl.mm#ID_1014457432">Knopen sorteren</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
<node TEXT="Formaat &amp; stijl" ID="ID_1603681371" CREATED="1319875570304" MODIFIED="1323790015455" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_183210534">Sjablonen</a>&#160;resp. <a href="freeplaneTutorial_nl.mm#ID_1724703419">Stijlen</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
<node ID="ID_1058310897" CREATED="1319923489096" MODIFIED="1321036106672" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Script</b>&#160;&amp; <b>Add-on</b>
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_519455593">Gebruiken en maken van een script</a>&#160;resp. <a href="freeplaneTutorial_nl.mm#ID_1156954596">Add-on</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
<node ID="ID_739070756" CREATED="1319915355170" MODIFIED="1321037295491" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Spellingscontrole </b>&#160;&amp; Academische schrijver suite
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i><a href="freeplaneTutorial_nl.mm#ID_141336344">Woordenlijsten voor spellingcontrole</a>&#160;resp. <a href="freeplaneTutorial_nl.mm#ID_170927482">Academische schrijvers suite</a>
      </li>

    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
</node>
<node TEXT="" POSITION="left" ID="ID_1736833399" CREATED="1455910866421" MODIFIED="1455910866421">
<hook NAME="SummaryNode"/>
<node TEXT="Groepsknoop&#xa;met accollade" ID="ID_499898058" CREATED="1319795597294" MODIFIED="1321037578474" HGAP_QUANTITY="40.0 px">
<font BOLD="true"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>Zie</b>
    </p>
    <ul>
      <li>
        <i>Help &gt; Handleiding: </i>&#160;<a href="freeplaneTutorial_nl.mm#ID_1700918771">Groepsknoop met accollade</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge COLOR="#ff00ff" WIDTH="3"/>
</node>
</node>
</node>
</map>
